"""
DO NOT EDIT! OR MODIFY:
Join us @starexxchat on Telegram
"""
import os, sys, traceback
from instabot import Bot
class instagram:
    def __init__(self):
        self.bot = None
        self.commandhandlers = {}
        self.messagehandler = None
        
    def commands(self, commandlist):
        def decorator(func):
            for cmd in commandlist:
                self.commandhandlers[cmd] = func
            return func
        return decorator
    
    def message(self):
        def decorator(func):
            self.messagehandler = func
            return func
        return decorator
    
    def run(self, username, password):
        try:
            self.bot = Bot()
            self.bot.login(username=username, password=password)
            
        except Exception:
            error = self.cleanerror()
            print(f"Error: {error}")
    
    def cleanerror(self):
        exc_type, exc_value, exc_traceback = sys.exc_info()
        tb_list = traceback.format_exception(exc_type, exc_value, exc_traceback)
        return tb_list[-1].strip()
    
    def process(self, result, user_id=None, username=None):
        try:
            if isinstance(result, dict):
                msgtype = result.get('type')
                
                if msgtype == 'dm':
                    text = result.get('text', '')
                    target_user = result.get('username', username)
                    
                    if target_user:
                        user_id = self.bot.get_user_id_from_username(target_user)
                    
                    if user_id:
                        self.bot.send_message(text, [user_id])
                
                elif msgtype == 'post':
                    self.bot.upload_photo(result['file'], caption=result.get('caption', ''))
                
                elif msgtype == 'video':
                    self.bot.upload_video(result['file'], caption=result.get('caption', ''))
                
                elif msgtype == 'story':
                    if result['file'].endswith(('.jpg', '.png', '.jpeg')):
                        self.bot.upload_story_photo(result['file'])
                    else:
                        self.bot.upload_story_video(result['file'])
                
                elif msgtype == 'profile':
                    return self.bot.get_user_info(result.get('username'))
                
                elif msgtype == 'followers':
                    return self.bot.get_user_followers(result.get('username'))
                
                elif msgtype == 'following':
                    return self.bot.get_user_following(result.get('username'))
                
                elif msgtype == 'follow':
                    self.bot.follow(result['username'])
                
                elif msgtype == 'unfollow':
                    self.bot.unfollow(result['username'])
                
                elif msgtype == 'like':
                    self.bot.like(result['media_id'])
                
                elif msgtype == 'unlike':
                    self.bot.unlike(result['media_id'])
                
                elif msgtype == 'comment':
                    self.bot.comment(result['media_id'], result['text'])
                
                elif msgtype == 'reply':
                    self.bot.reply_to_comment(result['media_id'], result['comment_id'], result['text'])
                
                elif msgtype == 'deletecomment':
                    self.bot.delete_comment(result['media_id'], result['comment_id'])
                
                elif msgtype == 'likecomment':
                    self.bot.like_comment(result['comment_id'])
                
                elif msgtype == 'unlikecomment':
                    self.bot.unlike_comment(result['comment_id'])
                
                elif msgtype == 'block':
                    self.bot.block(result['username'])
                
                elif msgtype == 'unblock':
                    self.bot.unblock(result['username'])
                
                elif msgtype == 'approve':
                    self.bot.approve_pending_friend_requests()
                
                elif msgtype == 'ignore':
                    self.bot.ignore_pending_friend_requests()
                
                elif msgtype == 'pending':
                    return self.bot.get_pending_friend_requests()
                
                elif msgtype == 'mediainfo':
                    return self.bot.get_media_info(result['media_id'])
                
                elif msgtype == 'userfeed':
                    return self.bot.get_user_feed(result.get('username'))
                
                elif msgtype == 'hashtagfeed':
                    return self.bot.get_hashtag_feed(result['hashtag'])
                
                elif msgtype == 'locationfeed':
                    return self.bot.get_location_feed(result['location_id'])
                
                elif msgtype == 'geofeed':
                    return self.bot.get_geotag_feed(result['location_id'])
                
                elif msgtype == 'saved':
                    return self.bot.get_saved_media()
                
                elif msgtype == 'archive':
                    self.bot.archive(result['media_id'])
                
                elif msgtype == 'unarchive':
                    self.bot.unarchive(result['media_id'])
                
                elif msgtype == 'highlight':
                    self.bot.create_highlight(result['media_ids'])
                
                elif msgtype == 'deletehighlight':
                    self.bot.delete_highlight(result['highlight_id'])
                
                elif msgtype == 'igtv':
                    self.bot.upload_igtv_video(result['file'], title=result.get('title'), caption=result.get('caption'))
                
                elif msgtype == 'reel':
                    self.bot.upload_reel_video(result['file'], caption=result.get('caption'))
                
                elif msgtype == 'bio':
                    self.bot.set_biography(result['text'])
                
                elif msgtype == 'website':
                    self.bot.set_website(result['url'])
                
                elif msgtype == 'private':
                    self.bot.set_account_private()
                
                elif msgtype == 'public':
                    self.bot.set_account_public()
                
                elif msgtype == 'storypoll':
                    self.bot.upload_story_poll(result['file'], question=result['question'], options=result['options'])
                
                elif msgtype == 'storyquestion':
                    self.bot.upload_story_question(result['file'], question=result['question'])
                
                elif msgtype == 'storyquiz':
                    self.bot.upload_story_quiz(result['file'], question=result['question'], options=result['options'], correct=result['correct'])
                
                elif msgtype == 'storyslider':
                    self.bot.upload_story_slider(result['file'], question=result['question'], emoji=result.get('emoji'))
                
                elif msgtype == 'storycountdown':
                    self.bot.upload_story_countdown(result['file'], text=result['text'], end_ts=result['end_ts'])
                
                elif msgtype == 'storymention':
                    self.bot.upload_story_mention(result['file'], user_ids=result['user_ids'])
                
                elif msgtype == 'storyhashtag':
                    self.bot.upload_story_hashtag(result['file'], hashtag=result['hashtag'])
                
                elif msgtype == 'storylocation':
                    self.bot.upload_story_location(result['file'], location_id=result['location_id'])
                
                elif msgtype == 'analytics':
                    return self.bot.get_insights()
                
                else:
                    return f"Unknown type: {msgtype}"
            else:
                return str(result)
                
        except Exception:
            error = self.cleanerror()
            return f"Error: {error}"


"""
DO NOT EDIT! OR MODIFY:
Join us @starexxchat on Telegram
"""
import sys, traceback, os, requests
from telebot.types import *
from io import BytesIO
import telebot

# main content telegram()
class telegram:
    def __init__(self):
        self.bot = None
        self.commandhandlers = {}
        self.messagehandler = None
        self.callbackhandler = None
        
    def commands(self, commandlist):
        def decorator(func):
            for cmd in commandlist:
                self.commandhandlers[cmd] = func
            return func
        return decorator
    
    def message(self):
        def decorator(func):
            self.messagehandler = func
            return func
        return decorator
    
    def callback(self):
        def decorator(func):
            self.callbackhandler = func
            return func
        return decorator
    
    def run(self, token):
        try:
            self.bot = telebot.TeleBot(token)
            
            for cmd, handler in self.commandhandlers.items():
                @self.bot.message_handler(commands=[cmd])
                def handlecommand(message, handler=handler):
                    try:
                        result = handler(message)
                        self.send(message, result)
                    except Exception:
                        error = self.cleanerror()
                        print(f"Error: {error}")
            
            if self.messagehandler:
                @self.bot.message_handler(func=lambda m: True)
                def handlemessage(message):
                    try:
                        result = self.messagehandler(message)
                        self.send(message, result)
                    except Exception:
                        error = self.cleanerror()
                        print(f"Error: {error}")
            
            if self.callbackhandler:
                @self.bot.callback_query_handler(func=lambda call: True)
                def handlecallback(call):
                    try:
                        result = self.callbackhandler(call)
                        self.send(call.message, result)
                    except Exception:
                        error = self.cleanerror()
                        print(f"Error: {error}")
            
            self.bot.polling(none_stop=True, timeout=60)
            
        except Exception:
            error = self.cleanerror()
            print(f"Error: {error}")
    
    def cleanerror(self):
        exc_type, exc_value, exc_traceback = sys.exc_info()
        tb_list = traceback.format_exception(exc_type, exc_value, exc_traceback)
        for i, line in enumerate(tb_list):
            line = line.replace('telebot.', 'mehta.')
            tb_list[i] = line
        return tb_list[-1].strip()
    
    def getfile(self, fileinput):
        if isinstance(fileinput, str):
            if fileinput.startswith(('http://', 'https://')):
                response = requests.get(fileinput)
                return BytesIO(response.content)
            elif os.path.exists(fileinput):
                with open(fileinput, 'rb') as f:
                    return BytesIO(f.read())
            else:
                return fileinput
        return fileinput
    
    def send(self, message, result):
        try:
            if isinstance(result, dict):
                msgtype = result.get('type', 'text')
                parse = result.get('parse')
                receiver = result.get('receiver', message.chat.id)
                replyto = result.get('reply_to', message.message_id)
                preview = result.get('preview', True)
                notify = result.get('notify', True)
                
                if msgtype == 'text':
                    self.bot.send_message(receiver, result['text'], parse_mode=parse, 
                                        reply_to_message_id=replyto, disable_web_page_preview=not preview, 
                                        disable_notification=not notify)
                
                elif msgtype == 'photo':
                    file = self.getfile(result['file'])
                    self.bot.send_photo(receiver, file, caption=result.get('caption'), 
                                      parse_mode=parse, reply_to_message_id=replyto, 
                                      disable_notification=not notify)
                
                elif msgtype == 'video':
                    file = self.getfile(result['file'])
                    self.bot.send_video(receiver, file, caption=result.get('caption'), 
                                      parse_mode=parse, reply_to_message_id=replyto, 
                                      disable_notification=not notify)
                
                elif msgtype == 'audio':
                    file = self.getfile(result['file'])
                    self.bot.send_audio(receiver, file, caption=result.get('caption'), 
                                      parse_mode=parse, reply_to_message_id=replyto, 
                                      disable_notification=not notify)
                
                elif msgtype == 'document':
                    file = self.getfile(result['file'])
                    self.bot.send_document(receiver, file, caption=result.get('caption'), 
                                         parse_mode=parse, reply_to_message_id=replyto, 
                                         disable_notification=not notify)
                
                elif msgtype == 'sticker':
                    file = self.getfile(result['file'])
                    self.bot.send_sticker(receiver, file, reply_to_message_id=replyto, 
                                        disable_notification=not notify)
                
                elif msgtype == 'voice':
                    file = self.getfile(result['file'])
                    self.bot.send_voice(receiver, file, caption=result.get('caption'), 
                                      parse_mode=parse, reply_to_message_id=replyto, 
                                      disable_notification=not notify)
                
                elif msgtype == 'animation':
                    file = self.getfile(result['file'])
                    self.bot.send_animation(receiver, file, caption=result.get('caption'), 
                                          parse_mode=parse, reply_to_message_id=replyto, 
                                          disable_notification=not notify)
                
                elif msgtype == 'location':
                    self.bot.send_location(receiver, result['lat'], result['lon'], 
                                         reply_to_message_id=replyto, disable_notification=not notify)
                
                elif msgtype == 'venue':
                    self.bot.send_venue(receiver, result['lat'], result['lon'], 
                                      result['title'], result['address'], reply_to_message_id=replyto, 
                                      disable_notification=not notify)
                
                elif msgtype == 'contact':
                    self.bot.send_contact(receiver, result['phone'], result['first_name'], 
                                        result.get('last_name'), reply_to_message_id=replyto, 
                                        disable_notification=not notify)
                
                elif msgtype == 'poll':
                    self.bot.send_poll(receiver, result['question'], result['options'], 
                                     reply_to_message_id=replyto, disable_notification=not notify)
                
                elif msgtype == 'dice':
                    self.bot.send_dice(receiver, result.get('emoji', '🎲'), 
                                     reply_to_message_id=replyto, disable_notification=not notify)
                
                elif msgtype == 'mediagroup':
                    media = []
                    for item in result['media']:
                        file = self.getfile(item['file'])
                        if item['type'] == 'photo':
                            media.append(InputMediaPhoto(file, caption=item.get('caption'), parse_mode=parse))
                        elif item['type'] == 'video':
                            media.append(InputMediaVideo(file, caption=item.get('caption'), parse_mode=parse))
                    self.bot.send_media_group(receiver, media, disable_notification=not notify)
                
                elif msgtype == 'keyboard':
                    markup = ReplyKeyboardMarkup(resize_keyboard=True)
                    for row in result['buttons']:
                        markup.add(*[KeyboardButton(btn) for btn in row])
                    self.bot.send_message(receiver, result['text'], reply_markup=markup, 
                                        parse_mode=parse, reply_to_message_id=replyto, 
                                        disable_web_page_preview=not preview, disable_notification=not notify)
                
                elif msgtype == 'inline':
                    markup = InlineKeyboardMarkup()
                    for row in result['buttons']:
                        rowbuttons = []
                        for btn in row:
                            if btn.get('url'):
                                rowbuttons.append(InlineKeyboardButton(btn['text'], url=btn['url']))
                            elif btn.get('data'):
                                rowbuttons.append(InlineKeyboardButton(btn['text'], callback_data=btn['data']))
                            else:
                                rowbuttons.append(InlineKeyboardButton(btn['text']))
                        markup.add(*rowbuttons)
                    self.bot.send_message(receiver, result['text'], reply_markup=markup, 
                                        parse_mode=parse, reply_to_message_id=replyto, 
                                        disable_web_page_preview=not preview, disable_notification=not notify)
                
                elif msgtype == 'removekeyboard':
                    self.bot.send_message(receiver, result['text'], 
                                        reply_markup=ReplyKeyboardRemove(), parse_mode=parse, 
                                        reply_to_message_id=replyto, disable_web_page_preview=not preview, 
                                        disable_notification=not notify)
                
                elif msgtype == 'forcereply':
                    self.bot.send_message(receiver, result['text'], 
                                        reply_markup=ForceReply(), parse_mode=parse, 
                                        reply_to_message_id=replyto, disable_web_page_preview=not preview, 
                                        disable_notification=not notify)
                
                elif msgtype == 'delete':
                    self.bot.delete_message(receiver, result.get('message_id', message.message_id))
                
                elif msgtype == 'edittext':
                    self.bot.edit_message_text(result['text'], receiver, 
                                             result.get('message_id', message.message_id), 
                                             parse_mode=parse, disable_web_page_preview=not preview)
                
                elif msgtype == 'editcaption':
                    self.bot.edit_message_caption(receiver, result.get('message_id', message.message_id), 
                                                caption=result['caption'], parse_mode=parse)
                
                elif msgtype == 'editmarkup':
                    markup = InlineKeyboardMarkup()
                    for row in result['buttons']:
                        rowbuttons = []
                        for btn in row:
                            if btn.get('url'):
                                rowbuttons.append(InlineKeyboardButton(btn['text'], url=btn['url']))
                            elif btn.get('data'):
                                rowbuttons.append(InlineKeyboardButton(btn['text'], callback_data=btn['data']))
                            else:
                                rowbuttons.append(InlineKeyboardButton(btn['text']))
                        markup.add(*rowbuttons)
                    self.bot.edit_message_reply_markup(receiver, result.get('message_id', message.message_id), 
                                                     reply_markup=markup)
                
                elif msgtype == 'pin':
                    self.bot.pin_chat_message(receiver, result.get('message_id', message.message_id), 
                                            disable_notification=not notify)
                
                elif msgtype == 'unpin':
                    self.bot.unpin_chat_message(receiver, result.get('message_id', message.message_id))
                
                elif msgtype == 'unpinall':
                    self.bot.unpin_all_chat_messages(receiver)
                
                elif msgtype == 'forward':
                    self.bot.forward_message(result['to'], receiver, 
                                           result.get('message_id', message.message_id), 
                                           disable_notification=not notify)
                
                elif msgtype == 'copy':
                    self.bot.copy_message(result['to'], receiver, 
                                        result.get('message_id', message.message_id), 
                                        caption=result.get('caption'), parse_mode=parse, 
                                        disable_notification=not notify)
                
                elif msgtype == 'ban':
                    self.bot.ban_chat_member(receiver, result['user'], 
                                           until_date=result.get('until'))
                
                elif msgtype == 'unban':
                    self.bot.unban_chat_member(receiver, result['user'])
                
                elif msgtype == 'kick':
                    self.bot.kick_chat_member(receiver, result['user'])
                
                elif msgtype == 'leave':
                    self.bot.leave_chat(receiver)
                
                elif msgtype == 'restrict':
                    self.bot.restrict_chat_member(receiver, result['user'], 
                                                until_date=result.get('until'),
                                                can_send_messages=result.get('send', False),
                                                can_send_media_messages=result.get('media', False),
                                                can_send_polls=result.get('polls', False),
                                                can_send_other_messages=result.get('other', False),
                                                can_add_web_page_previews=result.get('previews', False))
                
                elif msgtype == 'promote':
                    self.bot.promote_chat_member(receiver, result['user'],
                                               can_change_info=result.get('change_info', False),
                                               can_post_messages=result.get('post', False),
                                               can_edit_messages=result.get('edit', False),
                                               can_delete_messages=result.get('delete', False),
                                               can_invite_users=result.get('invite', False),
                                               can_restrict_members=result.get('restrict', False),
                                               can_pin_messages=result.get('pin', False),
                                               can_promote_members=result.get('promote', False))
                
                elif msgtype == 'settitle':
                    self.bot.set_chat_title(receiver, result['title'])
                
                elif msgtype == 'setdescription':
                    self.bot.set_chat_description(receiver, result['description'])
                
                elif msgtype == 'setphoto':
                    file = self.getfile(result['file'])
                    self.bot.set_chat_photo(receiver, file)
                
                elif msgtype == 'deletephoto':
                    self.bot.delete_chat_photo(receiver)
                
                elif msgtype == 'invitelink':
                    link = self.bot.export_chat_invite_link(receiver)
                    return f"{link}"
                
                elif msgtype == 'chatinfo':
                    info = self.bot.get_chat(receiver)
                    return str(info)
                
                elif msgtype == 'membercount':
                    count = self.bot.get_chat_members_count(receiver)
                    return f"{count}"
                
                elif msgtype == 'memberinfo':
                    info = self.bot.get_chat_member(receiver, result['user'])
                    return str(info)
                
                elif msgtype == 'answer':
                    self.bot.answer_callback_query(message.id, 
                                                 text=result.get('text'),
                                                 show_alert=result.get('alert', False))
                
                else:
                    self.bot.send_message(receiver, str(result), parse_mode=parse, 
                                        reply_to_message_id=replyto, disable_web_page_preview=not preview, 
                                        disable_notification=not notify)
            else:
                self.bot.reply_to(message, str(result))
                
        except Exception:
            error = self.cleanerror()
            print(f"Error: {error}")
            
            
            
            
            
            
            
            
            
            
            # DEV: @realstarexx / @starexx